// ----------------------------------------------------------------------------
// Copyright (C) 2014
//              David Freese, W1HKJ
//
// This file is part of flrig.
//
// flrig is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// flrig is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef _UI_H
#define _UI_H

#define TOUCH_MAINW 1024
#define TOUCH_MAINH 134

#define WIDE_MAINW 735
#define WIDE_MAINH 148
#define WIDE_MENUH 22
#define WIDE_TABSH 92

#define SMALL_MENUH 22
#define SMALL_MAINW 425
#define SMALL_MAINH 360

#endif

